use strict;
use warnings;
use Test::More tests => 4;

use_ok('WebService::Eventful');
use_ok('WebService::Eventful::REST');
use_ok('WebService::Eventful::YAML');
use_ok('WebService::Eventful::JSON');
